@@ -34,3 +34,11 @@ def createEvent(url, params, headers):
 def updateEvent(url, params, headers):
     r = requests.patch(url+'/events/'+params['event_id'], params=params, headers=headers)
     return r
+
+def refreshToken(url, params, headers):
+    r = requests.post(url+'/refresh', params=params, headers=headers)
+    return r
+		
+def revokeToken(url, params, headers):
+    r = requests.post(url+'/revoke', params=params, headers=headers)
+    return r
\ No newline at end of file
